package Bundle::Business::Shipping::UPS_Offline;

$VERSION = '1.01';

1;

__END__

=head1 NAME

Bundle::Business::Shipping::UPS_Offline

=head1 SYNOPSIS

 perl -MCPAN -e install Bundle::Business::Shipping::UPS_Offline

See the INSTALL file in Business::Shipping for more information.

=head1 CONTENTS

Bundle::Business::Shipping::Basic

Business::Shipping::DataFiles

Config::IniFiles

=head1 SEE ALSO

L<Business::Shipping>

=head1 AUTHOR

Dan Browning E<lt>F<db@kavod.com>E<gt>, Kavod Technologies, L<http://www.kavod.com>.

=head1 COPYRIGHT AND LICENCE

Copyright (c) 2003-2004 Kavod Technologies and Daniel Browning. All rights 
reserved.  This program is free software; you may redistribute it and/or modify
it under the same terms as Perl itself. See LICENSE for more info.

=cut
